<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Eliminar</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished">Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished">Presentación das diapositivas</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished">Exportar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished">Copiar</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished">Favorito</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished">Xira en sentido horario</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished">Xire en sentido antihorario</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="unfinished">Establecer como fondo de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished">Amosar no xestor de ficheiros</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished">Información da foto</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="unfinished">Restaurar</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>Sen nome</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Crear</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>Novo álbum</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>Está seguro que quere eliminar este álbum?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>Papeleira</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>Papeleira</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>Ou arrastre as fotos aquí</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>Importar todo</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>Importar a:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>Disco do sistema</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galería</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disco está ocupado, non se pode executar agora</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Substituír</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Gardar en:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Calidade:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>Seleccionar outros directorios</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>O nome do ficheiro non pode estar baleiro</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>xa existe. Quere sibstituílo?</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1 Drive</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>%1 disco en branco</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1 encriptado</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Volume</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>Exportar fotos</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>Eliminando...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>Restaurando...</translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this photo from the album?</source>
        <translation>Está certo/a de que quere eliminar esta foto do álbum?</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n photos from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Are you sure you want to delete this video from the album?</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n videos from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n items from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Información básica</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>Presentación das diapositivas</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galería</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Álbums</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Axuda</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Amosar no xestor de ficheiros</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentación das diapositivas</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Establecer como fondo de pantalla</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Xira en sentido horario</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Xire en sentido antihorario</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Posterior</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Non favorito</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>Volver a nomear o álbum</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>Álbum “%1” eliminado</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>Engadiuse con éxito a &quot;% 1&quot;</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Importar con éxito</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>Erro ao importar</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Erro ao exportar</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>Exportar con éxito</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>Todas as fotos</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>Prazos</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Álbums</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>Saír da pantalla completa/presentación das diapositivas</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Amosar atallos</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Seleccionar todo</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Ampliar</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Afastar</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Mover cara arriba polas páxinas</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Mover cara abaixo polas páxinas</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuracións</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Importando...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Eliminar</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>Lanterna</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Tamaño da fonte</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensións</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Datos collidos</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Datos modificados</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Modo exposición</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa de exposición</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tempo de exposición</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Apertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Distancia focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Apertura máxima</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Modo contador</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balance de brancos</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensación co flash</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modelo da cámara</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modelo dos lentes</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espazo de cor</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>Disco do sistema</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>Seleccionar</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Deseleccionar</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>Importado en</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %1-%2-%3 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>Importado en</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Restaurar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Xire en sentido antihorario</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Xira en sentido horario</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Importando...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>Sen resultados de busca</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>Presentación das diapositivas</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>Sen resultados de busca</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Non favorito</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Xira en sentido horario</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Xire en sentido antihorario</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Amosar no xestor de ficheiros</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Establecer como fondo de pantalla</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentación das diapositivas</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Información da foto</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Engadir ao álbum</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eliminar do álbum</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Restaurar</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novo álbum</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished">días</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished">Información básica</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation type="unfinished">Datos modificados</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Tipo</translation>
    </message>
    <message>
        <source>File size</source>
        <translation type="unfinished">Tamaño da fonte</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished">Datos collidos</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
